@@ -87,6 +87,7 @@ public:
 
     void registerCompletionModel(KTextEditor::CodeCompletionModel *model);
     void unregisterCompletionModel(KTextEditor::CodeCompletionModel *model);
+    bool isCompletionModelRegistered(KTextEditor::CodeCompletionModel *model) const;
 
     int automaticInvocationDelay() const;
     void setAutomaticInvocationDelay(int delay);
@@ -95,7 +96,7 @@ public:
         CompletionRange() : range(0)
         {
         }
-        CompletionRange(KTextEditor::MovingRange *r) : range(r)
+        explicit CompletionRange(KTextEditor::MovingRange *r) : range(r)
         {
         }
 
@@ -129,7 +130,7 @@ public:
     //Returns true if a screen border has been hit
     bool updatePosition(bool force = false);
 
-    virtual bool eventFilter(QObject *watched, QEvent *event);
+    bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
 
     KateArgumentHintTree *argumentHintTree() const;
 
@@ -163,9 +164,10 @@ public Q_SLOTS:
     void resetHadNavigation();
 
 protected:
-    virtual void showEvent(QShowEvent *event);
-    virtual void resizeEvent(QResizeEvent *event);
-//    virtual void focusInEvent ( QFocusEvent * event );
+    void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
+    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
+    void focusOutEvent(QFocusEvent * event) Q_DECL_OVERRIDE;
+
 
 private Q_SLOTS:
     void completionModelReset();
